summaryrefslogtreecommitdiffstats
path: root/cc/math_util.h
diff options
context:
space:
mode:
authorenne@chromium.org <enne@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-10-19 21:22:42 +0000
committerenne@chromium.org <enne@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-10-19 21:22:42 +0000
commitc753e25a8b4366c44134a8c21b9ed3392bf48608 (patch)
treef378c8a762caccf60856a1670ae33dfd638b9453 /cc/math_util.h
parent503160f80568f024fa712e280bb1a4e1e6ca1ec3 (diff)
downloadchromium_src-c753e25a8b4366c44134a8c21b9ed3392bf48608.zip
chromium_src-c753e25a8b4366c44134a8c21b9ed3392bf48608.tar.gz
chromium_src-c753e25a8b4366c44134a8c21b9ed3392bf48608.tar.bz2
Revert "cc: Rename cc classes and members to match filenames"
This reverts commit 184fac5add06d5f4670fa6be4a4d3b39232d51bb. git-svn-id: svn://svn.chromium.org/chrome/trunk/src@163059 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'cc/math_util.h')
-rw-r--r--cc/math_util.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/cc/math_util.h b/cc/math_util.h
index da3ba08..f0a36ab 100644
--- a/cc/math_util.h
+++ b/cc/math_util.h
@@ -38,7 +38,7 @@ struct HomogeneousCoordinate {
if (w == 1)
return FloatPoint(x, y);
// For now, because this code is used privately only by MathUtil, it should never be called when w == 0, and we do not yet need to handle that case.
DCHECK(w);
double invW = 1.0 / w;
return FloatPoint(x * invW, y * invW);
@@ -49,7 +49,7 @@ struct HomogeneousCoordinate {
if (w == 1)
return FloatPoint3D(x, y, z);
// For now, because this code is used privately only by MathUtil, it should never be called when w == 0, and we do not yet need to handle that case.
DCHECK(w);
double invW = 1.0 / w;
return FloatPoint3D(x * invW, y * invW, z * invW);
@@ -61,7 +61,7 @@ struct HomogeneousCoordinate {
double w;
};
-class MathUtil {
+class CCMathUtil {
public:
// Background: WebTransformationMatrix code in WebCore does not do the right thing in
@@ -38,7 +38,7 @@ struct HomogeneousCoordinate {
if (w == 1)
return FloatPoint(x, y);
- // For now, because this code is used privately only by MathUtil, it should never be called when w == 0, and we do not yet need to handle that case.
+ // For now, because this code is used privately only by CCMathUtil, it should never be called when w == 0, and we do not yet need to handle that case.
DCHECK(w);
double invW = 1.0 / w;
@@ -49,7 +49,7 @@ struct HomogeneousCoordinate {
if (w == 1)
return FloatPoint3D(x, y, z);
- // For now, because this code is used privately only by MathUtil, it should never be called when w == 0, and we do not yet need to handle that case.
+ // For now, because this code is used privately only by CCMathUtil, it should never be called when w == 0, and we do not yet need to handle that case.
DCHECK(w);
double invW = 1.0 / w;